@@ -2,10 +2,10 @@
 //!
 //! A Rust translation of [Minkukel][article]'s algorithm, which is claimed to provide **lunar data for a period of 1900-2100**.
 //!
-//! Input is a timestamp (`i64`), whether positive or negative. It's compatible with [chrono][chrono] `timestamp()` function.
+//! Input is a timestamp ([`i64`]), whether positive or negative. It's compatible with [`chrono::DateTime::timestamp()`][chrono] function.
 //!
 //! [article]: https://minkukel.com/en/various/calculating-moon-phase/
-//! [chrono]: https://docs.rs/chrono/
+//! [chrono]: https://docs.rs/chrono/latest/chrono/struct.DateTime.html#method.timestamp
 
 use float_extras::f64::fmod;
 
@@ -95,7 +95,7 @@ mod tests {
 
     // Fri Jan 10 07:23:00 PM UTC 2020
     #[test]
-    fn twenty_twenty_first_full_moon() {
+    fn twenty_twenty_ad_first_full_moon() {
         assert_eq!(verbal_phase(1578684180), String::from("full"))
     }
 
@@ -105,9 +105,15 @@ mod tests {
         assert_eq!(verbal_phase(1860900), String::from("full"))
     }
 
-    // Wed Jan 11 08:36:00 PM UTC 1933
+    // Thu Jan 1 12:00:00 AM UTC 1970
     #[test]
-    fn holodomor_moon() {
-        assert_eq!(verbal_phase(-1166671440), String::from("full"))
+    fn just_unix_timestamp() {
+        assert_eq!(verbal_phase(0), String::from("last quarter"))
+    }
+
+    // Tue Jan 14 10:21:00 PM UTC 1930
+    #[test]
+    fn nineteen_thirty_ad_first_full_moon() {
+        assert_eq!(verbal_phase(-1261100340), String::from("full"))
     }
 }
